#!/bin/bash

# Stop script on error
set -e

# Don't allow unassigned variables
set -u


##############
#
# Purpose:
# This script installs the Movek myMix Control web application an unmodifed
# plug computer.
#
##############


############## Script variables
# The root password for resulting myMix Control plug computers. Anyone who knows
# this password can get full root access to the plug computer!
rootpw="Aex4eewohv"


############## Confirm installation
# In case someone runs this script accedentally
read -p "Install myMix Control application on this computer? (y/N)" -n 1
echo ""
if [[ ! $REPLY =~ ^[Yy]$ ]]
then
	echo "Exiting..."
    exit 1
fi

# Print commands as they are executed for the remainder of the script
set -x


############## Prepare for installation
# change to the installation source directory
cd /media/usb
# extract the installation files if they haven't been already
if [ ! -f users.xml ]; then
    tar --no-same-owner --strip-components=1 -xzf install.tgz
fi


############## First, attempt installation items that are most likely to fail
# Install non-NAT wifi configuration
if [ -f /root/init_setup8787.sh ]; then
    cp init_setup8787.sh /root/init_setup8787.sh
elif [ -f /root/init_setup.sh ]; then
    cp init_setup.sh /root/init_setup.sh
else
    +x
    echo "Could not determine which wifi configuration to install, exiting...";
    exit 1
fi

############## Set wireless to enabled
touch /var/movek/enable_wireless
chown www-data:www-data /var/movek/enable_wireless


############## Install application
# Remove default plug application
rm -rf /var/www/*

# Install default application data, and clear any currently stored data.
if [ -d /var/movek ]; then
    rm -rf /var/movek
fi
mkdir /var/movek
mkdir /var/movek/active-project
cp users.xml /var/movek/
chown -R www-data:www-data /var/movek

# Install system (update) application
mkdir /var/www/system
tar --directory /var/www/system/ --strip-components=1 -xzf system.tgz

# Install myMix Control application
mkdir /var/www/app
tar --directory /var/www/app/ --strip-components=1 -xzf update.tgz
# This is not an update, so remove the post-update script
rm -rf /var/www/app/post-update/

# Make sure lighttpd has access to all the application folders
chown -R www-data:www-data /var/www

# Set hostname
cp etc-hostname /etc/hostname
chown root:root /etc/hostname
chmod 644 /etc/hostname

############## Change permissions and mountpoints
chown -R www-data:www-data /var/log/lighttpd
chmod 777 /tmp

# Mount tmpfs on /tmp if it isn't already
if [ $(grep -c "tmpfs /tmp tmpfs" /etc/fstab) -eq 0 ]
then
  echo "tmpfs /tmp tmpfs rw,noexec,nosuid,nodev 0 0" >> /etc/fstab
  rm -rf /tmp/*
  mount /tmp
fi

# Install configuration for usbmount so that www-data can write to USB drives
cp usbmount.conf /etc/usbmount/usbmount.conf
chown root:root /etc/usbmount/usbmount.conf
chmod 644 /etc/usbmount/usbmount.conf
usermod -a -G plugdev www-data


############## Install required software packages
dpkg --auto-deconfigure --force-confold -i packages/*.deb


############## Change/install config files
# Install PHP configuration
#/etc/php5/cgi/php.ini "session.save_path" = /tmp
cp php.ini /etc/php5/cgi/php.ini

# Enable php module
lighttpd-enable-mod fastcgi-php
/etc/init.d/lighttpd force-reload
#pwd=`pwd`
#cd /etc/lighttpd/conf-enabled/
#ln -s ../conf-available/15-fastcgi-php.conf
#cd "$pwd"

# Install lighttpd configuration
#enable alias for system application
cp lighttpd.conf /etc/lighttpd/lighttpd.conf

# Remove automatically installed index file
rm /var/www/index.lighttpd.html

# Install sudo access for the post-update script
cp sudoers /etc/sudoers
chown root:root /etc/sudoers
chmod 440 /etc/sudoers

# Add missing SUID bit to sudo
chmod u+s /usr/bin/sudo

# Install avahi-autoipd config to prevent bad DNS info from sticking around.
# This is required for sudo to function in a timely manner.
cp avahi-autoipd.action /etc/avahi/
chown root:root /etc/avahi/avahi-autoipd.action
chmod 755 /etc/avahi/avahi-autoipd.action

# Install avahi service to advertise the web interface.
# This allow the plugfinder PC app to discover plug computers.
cp mymix-control.service /etc/avahi/services/

# Install network interface configuration.
# This disables DHCP which is enabled on the default plug OS.
cp network-interfaces /etc/network/interfaces
chown root:root /etc/network/interfaces
chmod 644 /etc/network/interfaces

# Added 1/14/2013 for version 1.52
# See bugzilla 162
# Install ifplugd configuration.
# This disables the second DHCP client that wakes up periodically.
cp ifplugd.action /etc/ifplugd/ifplugd.action
chown root:root /etc/ifplugd/ifplugd.action
chmod 755 /etc/ifplugd/ifplugd.action

# Added 3/5/2013 for version 1.52
# See bugzilla 164
# Install mymix-discover to listen for layer 2 discovery messages
# Ignore errors from killall
set +e
killall -9 --quiet mymix-discover
# Reinstate error checking
set -e
cp mymix-discover /sbin/mymix-discover
chown root:root /sbin/mymix-discover
chmod 755 /sbin/mymix-discover
# Install new startup script to include mymix-discover
cp rc.local /etc/rc.local
chown root:root /etc/rc.local
chmod 755 /etc/rc.local

############## Change root password
passwd <<EOF
${rootpw}
${rootpw}
EOF

############## Sync changes to disk
sync


############## Print success message
set +x
echo ""
echo "############################"
echo "#                          #"
echo "# Installation successful! #"
echo "#                          #"
echo "############################"

############## End of script
